femputadora package
===================

Submodules
----------

femputadora.cli module
----------------------

.. automodule:: femputadora.cli
    :members:
    :undoc-members:
    :show-inheritance:

femputadora.femputadora module
------------------------------

.. automodule:: femputadora.femputadora
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: femputadora
    :members:
    :undoc-members:
    :show-inheritance:
